@@ -41,6 +41,20 @@ class VideoApi(BaseApi):
             **kwargs
         )
 
+    def delete(self, stream_id, **kwargs):
+        # type: (string_types, dict) -> None
+        """Delete Stream
+
+        :param stream_id: Id of the stream.
+        :type stream_id: string_types, required
+        """
+
+        self.api_client.delete(
+            '/streams/video/{stream_id}',
+            path_params={'stream_id': stream_id},
+            **kwargs
+        )
+
     def get(self, stream_id, **kwargs):
         # type: (string_types, dict) -> StreamsVideoResponse
         """Get Streams video by id
@@ -78,7 +92,7 @@ class VideoApi(BaseApi):
 
     def patch_streams_video(self, stream_id, streams_video_update_request, **kwargs):
         # type: (string_types, StreamsVideoUpdateRequest, dict) -> StreamsVideoResponse
-        """Update Streams video by id
+        """Partially update video stream by id
 
         :param stream_id: Id of the stream.
         :type stream_id: string_types, required
